@@ -3,7 +3,7 @@ require LWP::UserAgent;
 
 use vars qw(@ISA $VERSION);
 @ISA = qw(LWP::UserAgent);
-$VERSION = '1.08_02';
+$VERSION = '1.01';
 
 require HTTP::Request;
 require HTTP::Response;
@@ -11,7 +11,6 @@ require HTTP::Response;
 use HTTP::Status ();
 use strict;
 use Net::DNS;
-use LWP::Debug ();
 
 sub new {
     my $class = shift;
@@ -20,7 +19,6 @@ sub new {
     my $blocked_hosts     = delete $opts{blocked_hosts}     || [];
     my $whitelisted_hosts = delete $opts{whitelisted_hosts} || [];
     my $resolver          = delete $opts{resolver};
-    my $paranoid_proxy    = delete $opts{paranoid_proxy};
     $opts{timeout}      ||= 15;
 
     my $self = LWP::UserAgent->new( %opts );
@@ -28,7 +26,6 @@ sub new {
     $self->{'blocked_hosts'}     = $blocked_hosts;
     $self->{'whitelisted_hosts'} = $whitelisted_hosts;
     $self->{'resolver'}          = $resolver;
-    $self->{'paranoid_proxy'}    = $paranoid_proxy;
 
     $self = bless $self, $class;
     return $self;
@@ -50,7 +47,7 @@ sub _resolve {
     $depth ||= 0;
 
     die "CNAME recursion depth limit exceeded.\n" if $depth > 10;
-    die "DNS lookup resulted in bad host." if $self->_bad_host($host);
+    die "Suspicious results from DNS lookup" if $self->_bad_host($host);
 
     # return the IP address if it looks like one and wasn't marked bad
     return ($host) if $host =~ /^\d+\.\d+\.\d+\.\d+$/;
@@ -58,14 +55,10 @@ sub _resolve {
     my $sock = $res->bgsend($host)
         or die "No sock from bgsend";
 
-    # wait for the socket to become readable, unless this is from our test
-    # mock resolver.
-    unless ($sock && $sock eq "MOCK") {
-        my $rin = '';
-        vec($rin, fileno($sock), 1) = 1;
-        my $nf = select($rin, undef, undef, $self->_time_remain($request));
-        die "DNS lookup timeout" unless $nf;
-    }
+    my $rin = '';
+    vec($rin, fileno($sock), 1) = 1;
+    my $nf = select($rin, undef, undef, $self->_time_remain($request));
+    die "DNS lookup timeout" unless $nf;
 
     my $packet = $res->bgread($sock)
         or die "DNS bgread failure";
@@ -76,8 +69,7 @@ sub _resolve {
     foreach my $rr ($packet->answer) {
         if ($rr->type eq "A") {
             die "Suspicious DNS results from A record\n" if $self->_bad_host($rr->address);
-            # untaints the address:
-            push @addr, join(".", ($rr->address =~ /^(\d+)\.(\d+)\.(\d+)\.(\d+)$/));
+            push @addr, $rr->address;
         } elsif ($rr->type eq "CNAME") {
             # will be checked for validity in the recursion path
             $cname = $rr->cname;
@@ -94,7 +86,7 @@ sub _host_list_match {
     my $list_name = shift;
     my $host = shift;
 
-    foreach my $rule (@{ $self->{$list_name} || [] }) {
+    foreach my $rule (@{ $self->{$list_name} }) {
         if (ref $rule eq "CODE") {
             return 1 if $rule->($host);
         } elsif (ref $rule) {
@@ -156,7 +148,7 @@ sub _bad_host {
             $parts[1] > 0xff ||
             $parts[2] > 0xffff;
         $addr = pack("N", $parts[0] << 24 | $parts[1] << 16 | $parts[2]);
-    } elsif (@parts == 4) {
+    } else {
         # a.b.c.d - 8.8.8.8 bits
         return 1 if
             $parts[0] > 0xff ||
@@ -164,20 +156,15 @@ sub _bad_host {
             $parts[2] > 0xff ||
             $parts[3] > 0xff;
         $addr = pack("N", $parts[0] << 24 | $parts[1] << 16 | $parts[2] << 8 | $parts[3]);
-    } else {
-        return 1;
     }
 
     my $haddr = unpack("N", $addr); # host order IP address
     return 1 if
-        ($haddr & 0xFF000000) == 0x00000000 || # 0.0.0.0/8
         ($haddr & 0xFF000000) == 0x0A000000 || # 10.0.0.0/8
         ($haddr & 0xFF000000) == 0x7F000000 || # 127.0.0.0/8
         ($haddr & 0xFFF00000) == 0xAC100000 || # 172.16.0.0/12
-        ($haddr & 0xFFFF0000) == 0xA9FE0000 || # 169.254.0.0/16
         ($haddr & 0xFFFF0000) == 0xC0A80000 || # 192.168.0.0/16
-        ($haddr & 0xFFFFFF00) == 0xC0000200 || # 192.0.2.0/24  "TEST-NET" docs/example code
-        ($haddr & 0xFFFFFF00) == 0xC0586300 || # 192.88.99.0/24 6to4 relay anycast addresses
+        ($haddr & 0xFFFF0000) == 0xA9FE0000 || # 169.254.0.0/16
          $haddr               == 0xFFFFFFFF || # 255.255.255.255
         ($haddr & 0xF0000000) == 0xE0000000;  # multicast addresses
 
@@ -210,12 +197,6 @@ sub request {
         return $err_res;
     }
 
-    if (my $pp = $self->{paranoid_proxy}) {
-        $req->uri("$pp?url="   . eurl($req->uri) .
-                  "&timeout="  . ($self->{timeout}  + 0) .
-                  "&max_size=" . ($self->{max_size} + 0));
-    }
-
     return $self->SUPER::request($req, $arg, $size, $previous);
 }
 
@@ -314,12 +295,11 @@ EOT
             $response = $protocol->request($request, $proxy,
                                            $arg, $size, $timeout);
         };
-        my $error = $@ || $response->header( 'x-died' );
-        if ($error) {
-            $error =~ s/ at .* line \d+.*//s; # remove file/line number
+        if ($@) {
+            $@ =~ s/ at .* line \d+.*//s;  # remove file/line number
             $response = _new_response($request,
                                       &HTTP::Status::RC_INTERNAL_SERVER_ERROR,
-                                      $error);
+                                      $@);
         }
     }
     else {
@@ -331,7 +311,6 @@ EOT
     $response->request($request);  # record request for reference
     $cookie_jar->extract_cookies($response) if $cookie_jar;
     $response->header("Client-Date" => HTTP::Date::time2str(time));
-    $self->run_handlers("response_done", $response) if $self->can('run_handlers');
     return $response;
 }
 
@@ -344,7 +323,7 @@ sub blocked_hosts
         $self->{'blocked_hosts'} = \@hosts;
         return;
     }
-    return @{ $self->{'blocked_hosts'} || [] };
+    return @{ $self->{'blocked_hosts'} };
 }
 
 # whitelisted hostnames, compiled patterns, or subrefs
@@ -356,7 +335,7 @@ sub whitelisted_hosts
         $self->{'whitelisted_hosts'} = \@hosts;
         return;
     }
-    return @{ $self->{'whitelisted_hosts'} || [] };
+    return @{ $self->{'whitelisted_hosts'} };
 }
 
 # get/set Net::DNS resolver object
@@ -381,7 +360,7 @@ sub _need_proxy
 
     my $scheme = $url->scheme || return;
     if (my $proxy = $self->{'proxy'}{$scheme}) {
-        if ($self->{'no_proxy'} && @{ $self->{'no_proxy'} }) {
+        if (@{ $self->{'no_proxy'} }) {
             if (my $host = eval { $url->host }) {
                 for my $domain (@{ $self->{'no_proxy'} }) {
                     if ($host =~ /\Q$domain\E$/) {
@@ -431,13 +410,6 @@ sub _new_response {
     return $response;
 }
 
-sub eurl {
-    my $a = $_[0];
-    $a =~ s/([^a-zA-Z0-9_\,\-.\/\\\: ])/uc sprintf("%%%02x",ord($1))/eg;
-    $a =~ tr/ /+/;
-    return $a;
-}
-
 1;
 
 __END__
@@ -562,15 +534,6 @@ for somebody to enter in a good address in a subversive way.
 
 See L<LWP::UserAgent> to see how to use this class.
 
-http://contributing.appspot.com/lwpx-paranoidagent
-http://brad.livejournal.com/2409049.html
-https://github.com/collectiveintel/LWPx-ParanoidAgent
-http://search.cpan.org/dist/LWPx-ParanoidAgent
-
-=head1 ISSUES
-
-Report issues: https://github.com/collectiveintel/LWPx-ParanoidAgent/issues
-
 =head1 WARRANTY
 
 This module is supplied "as-is" and comes with no warranty, expressed
@@ -584,8 +547,7 @@ Maybe.  See the warranty above.
 
 =head1 COPYRIGHT
 
- Copyright 2005 Brad Fitzpatrick
- Copyright 2013 Wes Young (wesyoung.me)
+Copyright 2005 Brad Fitzpatrick
 
 Lot of code from the the base class, copyright 1995-2004 Gisle Aas.
 
